summaryrefslogtreecommitdiffstats
path: root/parts/filecreate/filecreate_part.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/filecreate/filecreate_part.cpp')
-rw-r--r--parts/filecreate/filecreate_part.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/parts/filecreate/filecreate_part.cpp b/parts/filecreate/filecreate_part.cpp
index 1c371177..75dfe5de 100644
--- a/parts/filecreate/filecreate_part.cpp
+++ b/parts/filecreate/filecreate_part.cpp
@@ -54,37 +54,37 @@
#include "config.h"
-static const KDevPluginInfo data("kdevfilecreate");
+static const KDevPluginInfo pluginData("kdevfilecreate");
typedef KDevGenericFactory<FileCreatePart> FileCreateFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( pluginData ) )
using namespace FileCreate;
FileCreatePart::FileCreatePart(TQObject *parent, const char *name, const TQStringList & )
-// : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
- : KDevCreateFile(&data, parent, name ? name : "FileCreatePart"), m_subPopups(0)
+// : KDevCreateFile(&pluginData, parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
+ : KDevCreateFile(&pluginData, parent, name ? name : "FileCreatePart"), m_subPopups(0)
{
setInstance(FileCreateFactory::instance());
setXMLFile("kdevpart_filecreate.rc");
- connect( core(), TQT_SIGNAL(projectOpened()), this, TQT_SLOT(slotProjectOpened()) );
- connect( core(), TQT_SIGNAL(projectClosed()), this, TQT_SLOT(slotProjectClosed()) );
+ connect( core(), TQ_SIGNAL(projectOpened()), this, TQ_SLOT(slotProjectOpened()) );
+ connect( core(), TQ_SIGNAL(projectClosed()), this, TQ_SLOT(slotProjectClosed()) );
_configProxy = new ConfigWidgetProxy( core() );
_configProxy->createProjectConfigPage( i18n("File Templates"), PROJECTSETTINGSPAGE, info()->icon() );
_configProxy->createGlobalConfigPage( i18n("File Templates"), GLOBALSETTINGSPAGE, info()->icon() );
- connect( _configProxy, TQT_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )),
- this, TQT_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )) );
+ connect( _configProxy, TQ_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )),
+ this, TQ_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )) );
- TDEToolBarPopupAction * newAction = new TDEToolBarPopupAction( i18n("&New"), "document-new", CTRL+TQt::Key_N, this, TQT_SLOT(slotNewFile()), actionCollection(), "file_new");
+ TDEToolBarPopupAction * newAction = new TDEToolBarPopupAction( i18n("&New"), "document-new", CTRL+TQt::Key_N, this, TQ_SLOT(slotNewFile()), actionCollection(), "file_new");
newAction->setWhatsThis( i18n("<b>New file</b><p>Creates a new file. Also adds it the project if the <b>Add to project</b> checkbox is turned on.") );
newAction->setToolTip( i18n("Create a new file") );
m_newPopupMenu = newAction->popupMenu();
- connect(m_newPopupMenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(slotAboutToShowNewPopupMenu()));
+ connect(m_newPopupMenu, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(slotAboutToShowNewPopupMenu()));
- TQTimer::singleShot( 0, this, TQT_SLOT(slotGlobalInitialize()) );
+ TQTimer::singleShot( 0, this, TQ_SLOT(slotGlobalInitialize()) );
}
@@ -105,14 +105,14 @@ void FileCreatePart::insertConfigWidget( const KDialogBase * dlg, TQWidget * pag
case PROJECTSETTINGSPAGE:
{
FCConfigWidget* w = new FCConfigWidget( this, false, page, "filecreate config widget" );
- connect( dlg, TQT_SIGNAL( okClicked( ) ), w, TQT_SLOT( accept( ) ) );
+ connect( dlg, TQ_SIGNAL( okClicked( ) ), w, TQ_SLOT( accept( ) ) );
}
break;
case GLOBALSETTINGSPAGE:
{
FCConfigWidget *w = new FCConfigWidget( this, true, page, "filecreate config widget" );
- connect(dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()));
+ connect(dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()));
}
break;
}
@@ -136,7 +136,7 @@ void FileCreatePart::slotAboutToShowNewPopupMenu()
filetype->icon(), TDEIcon::Desktop, TDEIcon::SizeSmall,
TDEIcon::DefaultState, NULL, true);
m_newPopupMenu->insertItem(iconPix, filetype->name(), this,
- TQT_SLOT(slotNewFilePopup(int)), 0, ++id );
+ TQ_SLOT(slotNewFilePopup(int)), 0, ++id );
m_newPopupMenu->setItemParameter( id, filetype->id() );
} else
{
@@ -151,7 +151,7 @@ void FileCreatePart::slotAboutToShowNewPopupMenu()
subtype->icon(), TDEIcon::Desktop, TDEIcon::SizeSmall,
TDEIcon::DefaultState, NULL, true);
subMenu->insertItem(iconPix, subtype->name(), this,
- TQT_SLOT(slotNewFilePopup(int)), 0, ++id );
+ TQ_SLOT(slotNewFilePopup(int)), 0, ++id );
subMenu->setItemParameter( id, subtype->id() );
}
}
@@ -187,7 +187,7 @@ void FileCreatePart::slotNewFile() {
}
void FileCreatePart::slotProjectOpened() {
- TQTimer::singleShot( 0, this, TQT_SLOT(slotInitialize()) );
+ TQTimer::singleShot( 0, this, TQ_SLOT(slotInitialize()) );
}
void FileCreatePart::addFileType(const TQString & filename) {
@@ -207,7 +207,7 @@ void FileCreatePart::addFileType(const TQString & filename) {
void FileCreatePart::slotProjectClosed() {
m_filetypes.clear();
- TQTimer::singleShot( 0, this, TQT_SLOT(slotGlobalInitialize()) );
+ TQTimer::singleShot( 0, this, TQ_SLOT(slotGlobalInitialize()) );
}
void FileCreatePart::slotFiletypeSelected(const FileType * filetype) {